@@ -28,7 +28,7 @@
 // Description:
 //    Implementation of Python servant object
 
-// $Id: pyServant.cc 5879 2009-06-18 09:05:20Z dgrisby $
+// $Id: pyServant.cc 6047 2011-06-20 22:14:34Z dgrisby $
 
 // $Log$
 // Revision 1.1.4.12  2009/05/06 16:50:28  dgrisby
@@ -383,6 +383,9 @@ Py_omniServant::_default_POA()
       // The call raised a Python exception
       omniORB::logs(1, "Python servant raised an exception in _default_POA.");
       omniPy::handlePythonException();
+#ifdef NEED_DUMMY_THROW
+      throw 0;
+#endif
     }
   }
   return 0;
